changeset 0bbbbce2bd3c in modules/account_statement_coda:default
details: 
https://hg.tryton.org/modules/account_statement_coda?cmd=changeset;node=0bbbbce2bd3c
description:
        Rename informations to information

        issue7926
        review54491002
diffstat:

 CHANGELOG                                 |   2 ++
 account.py                                |  12 ++++++------
 tests/scenario_account_statement_coda.rst |   2 +-
 3 files changed, 9 insertions(+), 7 deletions(-)

diffs (52 lines):

diff -r adc5f53d7d67 -r 0bbbbce2bd3c CHANGELOG
--- a/CHANGELOG Sat Jan 26 01:10:47 2019 +0100
+++ b/CHANGELOG Wed Feb 06 22:34:13 2019 +0100
@@ -1,3 +1,5 @@
+* Rename coda_informations to coda_information
+
 Version 5.0.0 - 2018-10-01
 * Bug fixes (see mercurial logs for details)
 * Remove support for Python 2.7
diff -r adc5f53d7d67 -r 0bbbbce2bd3c tests/scenario_account_statement_coda.rst
--- a/tests/scenario_account_statement_coda.rst Sat Jan 26 01:10:47 2019 +0100
+++ b/tests/scenario_account_statement_coda.rst Wed Feb 06 22:34:13 2019 +0100
@@ -116,5 +116,5 @@
     Decimal('100')
     >>> origin.description
     'COMMUNICATION'
-    >>> origin.informations['coda_bank_reference']
+    >>> origin.information['coda_bank_reference']
     'REF BANK             '

Reply via email to
diff -r adc5f53d7d67 -r 0bbbbce2bd3c account.py
--- a/account.py        Sat Jan 26 01:10:47 2019 +0100
+++ b/account.py        Wed Feb 06 22:34:13 2019 +0100
@@ -75,7 +75,7 @@
         origin.party = self.coda_party(coda_statement, move)
         # TODO select account using transaction codes
         origin.description = move.communication
-        origin.informations = self.coda_informations(coda_statement, move)
+        origin.information = self.coda_information(coda_statement, move)
         return [origin]
 
     def coda_party(self, coda_statement, move):
@@ -93,8 +93,8 @@
             if number.account.owners:
                 return number.account.owners[0]
 
-    def coda_informations(self, coda_statement, move):
-        informations = {}
+    def coda_information(self, coda_statement, move):
+        information = {}
         for name in [
                 'bank_reference',
                 'customer_reference',
@@ -109,6 +109,6 @@
                 'transaction_category']:
             value = getattr(move, name)
             if value:
-                informations['coda_' + name] = value
-        # TODO add move informations
-        return informations
+                information['coda_' + name] = value
+        # TODO add move information
+        return information